@@ -1227,7 +1227,12 @@ void ListViewDelegate::addTextPixmap(QPixmap** pp, SCRef txt, const QStyleOption
 
 	QFontMetrics fm(opt.font);
 	const unsigned int text_spacing = 4;
-	unsigned int text_width = fm.boundingRect(txt).width() + 2 * text_spacing;
+#if QT_VERSION >= QT_VERSION_CHECK(5,11,0)
+			unsigned int fmw = fm.horizontalAdvance(txt);
+#else
+			unsigned int fmw = fm.width(txt)
+#endif
+	unsigned int text_width = fmw + 2 * text_spacing;
 	unsigned int text_height = fm.height();
 
 	// Define size of the new Pixmap
@@ -1242,17 +1247,22 @@ void ListViewDelegate::addTextPixmap(QPixmap** pp, SCRef txt, const QStyleOption
 	QPainter p;
 	p.begin(newPm);
 
-	if (!pm->isNull()) {
-		newPm->fill(opt.palette.base().color());
-		p.drawPixmap(0, 0, *pm);
-	}
+	// TODO base palette color is not necessarily the background color of the
+	//  listview row this pixmap will be pasted into, e.g. in Qt themes that use
+	//  alternating backgrounds for listview rows.
+	newPm->fill(opt.palette.base().color());
+
+	// Add back what was there before.
+	if (!pm->isNull()) p.drawPixmap(0, 0, *pm);
 
 	p.setPen(opt.palette.color(QPalette::WindowText));
 	p.setBrush(opt.palette.color(QPalette::Window));
 	p.setFont(opt.font);
 
+	// Paint the new tag.
 	p.drawRect(offset, 0, text_width - 1, text_height - 1);
 	p.drawText(offset + text_spacing, fm.ascent(), txt);
+
 	p.end();
 
 	delete pm;
@@ -1321,7 +1331,7 @@ bool ListViewProxy::filterAcceptsRow(int source_row, const QModelIndex&) const {
 int ListViewProxy::setFilter(bool isOn, bool h, SCRef fl, int cn, ShaSet* s) {
 
 #if QT_VERSION >= 0x060000
-	filter = QRegularExpression::fromWildcard(fl, Qt::CaseInsensitive);
+	filter = QRegularExpression::fromWildcard(fl, Qt::CaseInsensitive, QRegularExpression::UnanchoredWildcardConversion);
 #else
 	filter = QRegExp(fl, Qt::CaseInsensitive, QRegExp::Wildcard);
 #endif
